@@ -25,7 +25,7 @@ class RestCall(Logger):
     _time_tracker_df  = DataFrame()
     _track_time = True
 
-    def __init__(self, base_url, user=None, password=None, track_time=False,log_level=INFO):
+    def __init__(self, base_url, user=None, password=None, basic_auth=None, track_time=False,log_level=INFO):
         super().__init__(level=log_level)
         if base_url[-1]=='/': 
             base_url=base_url[:-1]
@@ -40,13 +40,18 @@ class RestCall(Logger):
                     total = self._max_retries,
                     backoff_factor = 1,
                     status_forcelist = [408, 500, 502, 503, 504],
+#                    status_forcelist = [408],
                 )
         )
 
         self._session.mount('http://', self._adapter)
         self._session.mount('https://', self._adapter)
 
-        self._auth = HTTPBasicAuth(user, password)
+        if basic_auth is None:
+            self._auth = HTTPBasicAuth(user, password)
+        else:
+            self._auth = basic_auth
+
         self._session.headers.update({'Accept': 'application/json'})
         #self._session.headers.update({'Authorization': self._auth})
 
